1. Pre-compiled datasets — CpGtools documentation

# 1. Pre-compiled datasets

## 1.1. Test datasets

Test dataset can be downloaded from this link

## 1.2. Reference gene models

Reference gene model files can be downloaded from this link

## 1.3. Annotation datasets

> - pre-built TSV file used to annotate CpG according to its 450K/850K probe ID.

> > - MethylationEPIC_CpGtools.tsv.gz

> - BED files used to annotate CpG according to its genomic positions (hg19/GRCh37)

> > - hg19_ENCODE_338TF_130Cell_E3.bed.gz

> > - hg19_ENCODE_DNaseI_125Cells_V3.bed.gz

> > - hg19_ENCODE_H3K27ac_11_cellLines_ChIP.bed.gz

> > - hg19_ENCODE_H3K4me1_11_cellLines_ChIP.bed.gz

> > - hg19_ENCODE_H3K4me3_11_cellLines_ChIP.bed.gz

> > - hg19_ENCODE_chromHMM_states_9Cells.merge.bed.gz

> > - hg19_FANTOM_enhancers_phase_1_and_2.bed.gz

> - BED files used to annotate CpG according to its genomic locations (hg38/GRCh38)

> > - hg38_ENCODE_338TF_130Cell_E3.bed.gz

> > - hg38_ENCODE_DNaseI_125Cells_V3.bed.gz

> > - hg38_ENCODE_H3K27ac_11_cellLines_ChIP.bed.gz

> > - hg38_ENCODE_H3K4me1_11_cellLines_ChIP.bed.gz

> > - hg38_ENCODE_H3K4me3_11_cellLines_ChIP.bed.gz

> > - hg38_ENCODE_chromHMM_states_9Cells.merge.bed.gz

> > - hg38_FANTOM_enhancers_phase_1_and_2.bed.gz